@@ -1,8 +1,10 @@
 /* json-version.h - JSON-GLib versioning information
  * 
  * This file is part of JSON-GLib
- * Copyright (C) 2007  OpenedHand Ltd.
- * Copyright (C) 2009  Intel Corp.
+ *
+ * SPDX-FileCopyrightText: 2007  OpenedHand Ltd.
+ * SPDX-FileCopyrightText: 2009  Intel Corp.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,8 +23,7 @@
  *   Emmanuele Bassi  <ebassi@linux.intel.com>
  */
 
-#ifndef __JSON_VERSION_H__
-#define __JSON_VERSION_H__
+#pragma once
 
 #if !defined(__JSON_GLIB_INSIDE__) && !defined(JSON_COMPILATION)
 #error "Only <json-glib/json-glib.h> can be included directly."
@@ -40,21 +41,21 @@
  *
  * Json minor version component (e.g. 2 if `JSON_VERSION` is "1.2.3")
  */
-#define JSON_MINOR_VERSION              (8)
+#define JSON_MINOR_VERSION              (10)
 
 /**
  * JSON_MICRO_VERSION:
  *
  * Json micro version component (e.g. 3 if `JSON_VERSION` is "1.2.3")
  */
-#define JSON_MICRO_VERSION              (0)
+#define JSON_MICRO_VERSION              (6)
 
 /**
  * JSON_VERSION
  *
  * The version of JSON-GLib.
  */
-#define JSON_VERSION                    (1.8.0)
+#define JSON_VERSION                    (1.10.6)
 
 /**
  * JSON_VERSION_S:
@@ -62,7 +63,7 @@
  * The version of JSON-GLib, encoded as a string, useful for printing and
  * concatenation.
  */
-#define JSON_VERSION_S                  "1.8.0"
+#define JSON_VERSION_S                  "1.10.6"
 
 /**
  * JSON_ENCODE_VERSION:
@@ -99,5 +100,3 @@
          (JSON_MAJOR_VERSION == (major) && JSON_MINOR_VERSION > (minor)) || \
          (JSON_MAJOR_VERSION == (major) && JSON_MINOR_VERSION == (minor) && \
           JSON_MICRO_VERSION >= (micro)))
-
-#endif /* __JSON_VERSION_H__ */
